@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use strict;
 use warnings;
@@ -177,10 +177,11 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
+  use Future::IO::Impl::IOAsync; # for asynchronous playing
   use MIDI::RtMidi::ScorePlayer ();
   use MIDI::Util qw(setup_score);
 
@@ -219,7 +220,7 @@ version 0.0300
   use MIDI::RtMidi::FFI::Device ();
   my $midi_output = RtMidiOut->new;
 
-  MIDI::RtMidi::ScorePlayer->new(
+  my $sp = MIDI::RtMidi::ScorePlayer->new(
       score    => $score, # required MIDI score object
       parts    => [ \&bass, [ \&treble, \&bass ], \&bass ], # required part functions
       common   => \%common, # arguments given to the part functions
@@ -232,10 +233,11 @@ version 0.0300
       dump     => 0, # dump the score before each play (default: 0)
       port     => qr/iac/i,     # optional non-existing device
       device   => $midi_output, # optional existing object
-  )->play; # <- blocking
+  );
 
-  # OR play asynchronously:
-  MIDI::RtMidi::ScorePlayer->new->play_async->retain;
+  $sp->play; # blocking
+  # Or play asynchronously:
+  $sp->play_async->retain;
 
 =head1 DESCRIPTION
 
